import express, {Request, Response} from 'express';
import {model, Schema, HydratedDocument, Types} from 'mongoose';
import multer from 'multer';
import fs from 'fs';
import path from 'path';
import {IArtist} from './artist';

const upload = multer({dest: 'uploads/albums'});
const router = express.Router();

interface IAlbum {
	name: string;
	albumImage: File;
	year: number;
	artist: Types.ObjectId;
}

const Album = model<IAlbum>(
	'Album',
	new Schema({
		artist: {
			type: Schema.Types.ObjectId,
			ref: 'Artist',
		},
		name: String,
		year: Number,
		albumImage: {
			data: Buffer,
			contentType: String,
		},
	})
);

router.get('/', async (req: Request, res: Response) => {
	const albums = await Album.find().populate<{artist: IArtist}>('artist');
	res.send(albums);
});

router.post(
	'/',
	upload.single('albumImage'),
	async (req: Request, res: Response) => {
		const album: HydratedDocument<IAlbum> = new Album({
			name: req.body.name,
			albumImage: {
				data: fs.readFileSync(
					path.join('uploads/albums/' + req.file?.filename)
				),
				contentType: 'image',
			},
			year: req.body.year,
			artist: req.body.artist,
		});
		await album.save();

		res.send('Sucessfully saved');
	}
);

export {router as albumRouter};
